@@ -53,6 +53,12 @@ def put(session, scan, *filenames, **kwargs):
         upload the dataset to. If not provided the format
         will be determined from the file extension (i.e.
         in most cases it won't be necessary to specify
+    project_id : str
+        The ID of the project to upload the dataset to
+    subject_id : str
+        The ID of the subject to upload the dataset to
+    scan_id : str
+        The ID for the scan (defaults to the scan type)
     user : str
         The user to connect to the server with
     loglevel : str
@@ -78,6 +84,9 @@ def put(session, scan, *filenames, **kwargs):
     overwrite = kwargs.pop('overwrite', False)
     create_session = kwargs.pop('create_session', False,)
     resource_name = kwargs.pop('resource_name', None)
+    project_id = kwargs.pop('project_id', None)
+    subject_id = kwargs.pop('subject_id', None)
+    scan_id = kwargs.pop('scan_id', None)
     # If a single directory is provided, upload all files in it that
     # don't start with '.'
     if len(filenames) == 1 and isinstance(filenames[0], (list, tuple)):
@@ -97,11 +106,10 @@ def put(session, scan, *filenames, **kwargs):
                 raise XnatUtilsUsageError(
                     "The file to upload, '{}', does not exist"
                     .format(fname))
-    if sanitize_re.match(session) or session.count('_') < 2:
+    if sanitize_re.match(session):
         raise XnatUtilsUsageError(
             "Session '{}' is not a valid session name (must only contain "
-            "alpha-numeric characters and at least two underscores"
-            .format(session))
+            "alpha-numeric characters and underscores)".format(session))
     if illegal_scan_chars_re.search(scan) is not None:
         raise XnatUtilsUsageError(
             "Scan name '{}' contains illegal characters".format(scan))
@@ -136,8 +144,19 @@ def put(session, scan, *filenames, **kwargs):
             xsession = login.experiments[session]
         except KeyError:
             if create_session:
-                project_id = session.split('_')[0]
-                subject_id = '_'.join(session.split('_')[:2])
+                if project_id is None and subject_id is None:
+                    try:
+                        project_id, subject_id, _ = session.split('_')
+                    except ValueError:
+                        raise XnatUtilsUsageError(
+                            "Must explicitly provide project and subject IDs "
+                            "if session ID ({}) scheme doesn't match "
+                            "<project>_<subject>_<visit> convention, i.e. "
+                            "have exactly 2 underscores".format(session))
+                if project_id is None:
+                    project_id = session.split('_')[0]
+                if subject_id is None:
+                    subject_id = '_'.join(session.split('_')[:2])
                 try:
                     xproject = login.projects[project_id]
                 except KeyError:
@@ -158,7 +177,8 @@ def put(session, scan, *filenames, **kwargs):
                     "'{}' session does not exist, to automatically create it "
                     "please use '--create_session' option."
                     .format(session))
-        xdataset = scan_cls(id=scan, type=scan, parent=xsession)
+        xdataset = scan_cls(id=(scan_id if scan_id is not None else scan),
+                            type=scan, parent=xsession)
         if overwrite:
             try:
                 xdataset.resources[resource_name].delete()
@@ -257,6 +277,12 @@ def parser():
                               "format will be determined from the file "
                               "extension (i.e. in most cases it won't be "
                               "necessary to specify"))
+    parser.add_argument('--project_id', '-p',
+                        help="Provide the project ID if session doesn't exist")
+    parser.add_argument('--subject_id', '-b',
+                        help="Provide the subject ID if session doesn't exist")
+    parser.add_argument('--scan_id', type=str,
+                        help="Provide the scan ID (defaults to the scan type)")
     add_default_args(parser)
     return parser
 
@@ -270,7 +296,9 @@ def cmd(argv=sys.argv[1:]):
     try:
         put(args.session, args.scan, *args.filenames, overwrite=args.overwrite,
             create_session=args.create_session, resource_name=args.resource,
-            user=args.user, server=args.server, use_netrc=(not args.no_netrc))
+            project_id=args.project_id, subject_id=args.subject_id,
+            scan_id=args.scan_id, user=args.user, server=args.server,
+            use_netrc=(not args.no_netrc))
     except XnatUtilsUsageError as e:
         print_usage_error(e)
     except XNATResponseError as e:
